@@ -38,7 +38,9 @@ namespace aoflagger {
 		/** @brief Parkes, the single dish telescope in New South Wales. */
 		PARKES_TELESCOPE,
 		/** @brief WSRT, the Westerbork Synthesis Radio Telescope in the Netherlands. */
-		WSRT_TELESCOPE
+		WSRT_TELESCOPE,
+		/** @brief The AARTFAAC telescope, correlating the superterp antennas of LOFAR. */
+		AARTFAAC_TELESCOPE
 	};
 
 	/** @brief Lists the flags that can be used to alter a default strategy.
@@ -169,6 +171,9 @@ namespace aoflagger {
 		public:
 			friend class AOFlagger;
 			
+			/** @brief Construct an empty ImageSet. */
+			ImageSet();
+			
 			/** @brief Copy the image set. Only references to images are copied. */
 			ImageSet(const ImageSet& sourceImageSet);
 			
@@ -282,6 +287,11 @@ namespace aoflagger {
 		public:
 			friend class AOFlagger;
 			
+			/** @brief Construct an empty FlagMask.
+			 * The properties of empty FlagMask can not be accessed.
+			 */
+			FlagMask();
+			
 			/** @brief Copy a flag mask. Only copies a reference, not the data. */
 			FlagMask(const FlagMask& sourceMask);
 			
@@ -331,7 +341,6 @@ namespace aoflagger {
 			const bool *Buffer() const;
 			
 		private:
-			FlagMask();
 			FlagMask(size_t width, size_t height);
 			FlagMask(size_t width, size_t height, bool initialValue);
 			
