@@ -18,7 +18,7 @@ class ThresholdConfig {
 		
 		void InitializeThresholdsFromFirstThreshold(num_t firstThreshold, enum Distribution noiseDistribution);
 		
-		void Execute(const Image2D* image, Mask2D* mask, bool additive, num_t sensitivity) const;
+		void Execute(const Image2D* image, Mask2D* mask, bool additive, num_t timeSensitivity, num_t frequencySensitivity) const;
 		void SetVerbose(bool verbose) { _verbose = verbose; }
 		void SetMethod(Method method) { _method = method; }
 		
